.. _sec-user_guide-data-atmosphere_radprops:

Atmosphere: radiative properties
================================

An atmospheric radiative property data set provides collision (absorption,
extinction and scattering) coefficient and albedo values within the atmosphere.

Data access
-----------

Atmospheric radiative property data sets are generated by the
:meth:`.RadProfile.eval_dataset` method.

Structure
---------

Atmospheric radiative property data sets include four data variables:

* the absorption coefficient (``sigma_a``),
* the extinction coefficient (``sigma_t``),
* the scattering coefficient (``sigma_s``),
* the albedo (``albedo``),

two :term:`dimension coordinates <dimension coordinate>`:

* the wavelength (``w``),
* the layer altitude (``z_layer``),

and one :term:`non-dimension coordinate`:

* the level altitude (``z_level``).

All data variables are tabulated against ``w`` and ``z_layer``.
